@@ -47,8 +47,20 @@ class Storage(APIClientBase):
     def stop_pool_scrub(self, pool_name: str):
         return self.put_request("/pools/{pool_name}/scrub/stop", pool_name=pool_name)
 
-    def get_volumes(self):
-        return self.get_request("/volumes")
+    def get_volumes(
+        self,
+        volume_type: str = "NFS",
+        only_clones: bool = False,
+        label_key: str = "",
+    ):
+        return self.get_request(
+            "/volumes",
+            query_args={
+                "volume_type": volume_type,
+                "only_clones": only_clones,
+                "label_key": label_key,
+            },
+        )
 
     def create_volume(
         self, pool_name: str, ips: list, volume_type: str = "NFS", quota: str = "none"
@@ -145,8 +157,22 @@ class Storage(APIClientBase):
             snapshot_name=snapshot_name,
         )
 
-    def get_volume_files(self, volume_id: str):
-        return self.get_request("/volumes/{volume_id}/files", volume_id=volume_id)
+    def get_volume_files(
+        self,
+        volume_id: str,
+        path: str = "",
+        recursive: bool = False,
+        match_pattern: str = "",
+    ):
+        return self.get_request(
+            "/volumes/{volume_id}/files",
+            volume_id=volume_id,
+            query_args={
+                "path": path,
+                "recursive": recursive,
+                "match_pattern": match_pattern,
+            },
+        )
 
     def delete_volume_files(
         self, volume_id: str, file_path: str = None, pattern: str = None
@@ -196,4 +222,4 @@ class Storage(APIClientBase):
         )
 
     def get_system_information(self):
-        return self.get_request("/system")
\ No newline at end of file
+        return self.get_request("/system")
