@@ -4,17 +4,21 @@ from .api_client import APIClientBase, APIException
 
 class Virtualization(APIClientBase):
     def __init__(self, url_base=None, **kwargs):
-        super().__init__(
-            url_base or os.environ.get("VIRTUALIZATION_SERVICE", ""), **kwargs
-        )
+        super().__init__(url_base or os.environ.get("VIRTUALIZATION_SERVICE", ""), **kwargs)
+
+        # Deprecated methods, please don't use them
+        self.get_vm_by_syn_id = self.get_virtual_machine
 
     def get_hypervisors(self):
         return self.get_request("/hypervisors")
 
+    def get_hypervisor(self, hypervisor_id: str):
+        return self.get_request("/hypervisors/{uuid}", uuid=hypervisor_id)
+
     def get_vms(self):
         return self.get_request("/vms")
 
-    def get_vm_by_syn_id(self, vm_syn_id: str):
+    def get_virtual_machine(self, vm_syn_id: str):
         return self.get_request("/vms/{vm_syn_id}", vm_syn_id=vm_syn_id)
 
     def edit_vm(self, vm_syn_id: str, body: dict):
@@ -31,11 +35,7 @@ class Virtualization(APIClientBase):
         return next((snap for snap in snapshots if snap["name"] == snapshot_name), None)
 
     def create_vm_snapshot(
-        self,
-        vm_syn_id: str,
-        snapshot_name: str,
-        quiesce: bool = True,
-        dumpmem: bool = False,
+        self, vm_syn_id: str, snapshot_name: str, quiesce: bool = True, dumpmem: bool = False,
     ):
         body = {
             "vmSynId": vm_syn_id,
@@ -45,13 +45,10 @@ class Virtualization(APIClientBase):
             "dumpmem": dumpmem,
         }
         return self.post_request(
-            "/vmware/vms/{vm_syn_id}/snapshots",
-            vm_syn_id=vm_syn_id,
-            query_args={"in_background": "False"},
-            body=body,
+            "/vmware/vms/{vm_syn_id}/snapshots", vm_syn_id=vm_syn_id, query_args={"in_background": "False"}, body=body,
         )
 
-    def delete_vm_snapshot(self, vm_syn_id, snapshot_ref_id, consolidate = True, remove_children = True):
+    def delete_vm_snapshot(self, vm_syn_id, snapshot_ref_id, consolidate=True, remove_children=True):
         body = {
             "vmSynId": vm_syn_id,
             "snapshotRefId": snapshot_ref_id,
@@ -66,9 +63,7 @@ class Virtualization(APIClientBase):
             success_codes=[200, 202, 204],
         )
 
-    def create_nas_datastore(
-        self, server: str, mountpoint: str, hosts_syn_ids=None, datastore_name=None
-    ):
+    def create_nas_datastore(self, server: str, mountpoint: str, hosts_syn_ids=None, datastore_name=None):
         return self.post_request(
             "/vmware/datastores",
             body={
@@ -83,8 +78,5 @@ class Virtualization(APIClientBase):
     def delete_nas_datastore(self, syn_id: str = None, mountpoint: str = None):
         return self.delete_request(
             "/vmware/datastores",
-            query_args={
-                "datastore_syn_id": syn_id if syn_id else "",
-                "datastore_mountpoint": mountpoint,
-            },
+            query_args={"datastore_syn_id": syn_id if syn_id else "", "datastore_mountpoint": mountpoint},
         )
